@@ -284,7 +284,13 @@ def is_hidden_Darwin(path):
     return res[1]
 
 
-FilesSpec = Dict[str, Union[str, bytes, 'FilesSpec']]  # type: ignore
+class Symlink(str):
+    """
+    A string indicating the target of a symlink.
+    """
+
+
+FilesSpec = Dict[str, Union[str, bytes, Symlink, 'FilesSpec']]  # type: ignore
 
 
 @runtime_checkable
@@ -301,6 +307,9 @@ class TreeMaker(Protocol):
     def write_bytes(self, content):
         ...  # pragma: no cover
 
+    def symlink_to(self, target):
+        ...  # pragma: no cover
+
 
 def _ensure_tree_maker(obj: Union[str, TreeMaker]) -> TreeMaker:
     return obj if isinstance(obj, TreeMaker) else pathlib.Path(obj)  # type: ignore
@@ -324,12 +333,16 @@ def build(
     ...             "__init__.py": "",
     ...         },
     ...         "baz.py": "# Some code",
-    ...     }
+    ...         "bar.py": Symlink("baz.py"),
+    ...     },
+    ...     "bing": Symlink("foo"),
     ... }
     >>> target = getfixture('tmp_path')
     >>> build(spec, target)
     >>> target.joinpath('foo/baz.py').read_text(encoding='utf-8')
     '# Some code'
+    >>> target.joinpath('bing/bar.py').read_text(encoding='utf-8')
+    '# Some code'
     """
     for name, contents in spec.items():
         create(contents, _ensure_tree_maker(prefix) / name)
@@ -351,6 +364,11 @@ def _(content: str, path):
     path.write_text(content, encoding='utf-8')
 
 
+@create.register
+def _(content: Symlink, path):
+    path.symlink_to(content)
+
+
 class Recording:
     """
     A TreeMaker object that records everything that would be written.
@@ -375,3 +393,6 @@ class Recording:
 
     def mkdir(self, **kwargs):
         return
+
+    def symlink_to(self, target):
+        pass
